note

# XMLRésuméLibrary: User Guide

node | Element Reference | objective

## Name

note — Additional information

## Synopsis

### Content Model

    (para+)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `note` element contains additional information about its parent element.

### Parents

`note` may be contained in these elements: `academics`, `clearance`, `gpa`

## See Also

`annotation`, `legalnotice`.

## Examples

    <academics>
      <degrees>
        ...
      </degrees>
      <note>
        <para>
          I take education very seriously. After all, I'm in 37th grade now!
        </para>
      </note>
    </academics>

node | Element Reference | objective